@@ -33,7 +33,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dproc.c,v 1.21 2002/01/14 15:54:11 abe Exp $";
+static char *rcsid = "$Id: dproc.c,v 1.23 2005/08/08 19:56:44 abe Exp $";
 #endif
 
 #include "lsof.h"
@@ -66,6 +66,13 @@ _PROTOTYPE(static void process_text,(KA_T tp));
 _PROTOTYPE(static void read_proc,(void));
 
 
+/*
+ * Local defintions
+ */
+
+#define	PAPSINCR	1024		/* Pa and Ps table increment */
+#define	PAPSINIT	512		/* Pa and Ps table initial size */
+
 
 /*
  * Local static values
@@ -789,6 +796,7 @@ process_text(tp)
 static void
 read_proc()
 {
+	static int ap = 0;
 	MALLOC_S len;
 	struct proc *p;
 	KA_T pa;
@@ -807,7 +815,7 @@ read_proc()
 		(void) fprintf(stderr, "%s: proc table has no entries\n", Pn);
 		Exit(1);
 	    }
-	    len = (MALLOC_S)(Np * sizeof(struct proc));
+	    len = (MALLOC_S)(PAPSINIT * sizeof(struct proc));
 	    if (!(Ps = (struct proc *)malloc(len))) {
 		(void) fprintf(stderr, "%s: no proc table space (%d bytes)\n",
 		    Pn, len);
@@ -818,7 +826,7 @@ read_proc()
 	/*
 	 * Allocate kernel proc address table space.
 	 */
-	    len = (MALLOC_S)(Np * sizeof(KA_T));
+	    len = (MALLOC_S)(PAPSINIT * sizeof(KA_T));
 	    if (!(Pa = (KA_T *)malloc(len))) {
 		(void) fprintf(stderr,
 		    "%s: no proc address table space (%d bytes)\n", Pn, len);
@@ -826,6 +834,7 @@ read_proc()
 	    }
 #endif	/* DUV>=30000 */
 
+	    ap = PAPSINIT;
 	}
 /*
  * Try to read the proc structure table PROCTRYLM times.
@@ -834,6 +843,32 @@ read_proc()
 	for (try = 0; try < PROCTRYLM; try++) {
 	    for (p = Ps, Psn = px = 0; px < Np; px++) {
 
+	    /*
+	     * Insure Ps and Psa space.
+	     */
+		if (Psn >= ap) {
+		    ap += PAPSINCR;
+		    len = (MALLOC_S)(ap * sizeof(struct proc));
+		    if (!(Ps = (struct proc *)realloc((MALLOC_P *)Ps, len))) {
+			(void) fprintf(stderr,
+			    "%s: no more proc table space (%d bytes)\n",
+			    Pn, len);
+			Exit(1);
+		    }
+		    p = &Ps[Psn];
+
+#if	DUV>=30000
+		    len = (MALLOC_S)(ap * sizeof(KA_T));
+		    if (!(Pa = (KA_T *)realloc((MALLOC_P *)Pa, len))) {
+			(void) fprintf(stderr,
+			    "%s: no more proc address table space (%d bytes)\n",
+			    Pn, len);
+			Exit(1);
+		    }
+#endif	/* DUV>=30000 */
+
+		}
+
 #if     DUV<30000
 		pa = Kp + (KA_T)(px * sizeof(struct proc));
 		if (kread(pa, (char *)p, sizeof(struct proc)))
@@ -872,6 +907,7 @@ read_proc()
 	 * Reduce the local proc structure tables to their minimum if
 	 * not in repeat mode.
 	 */
+	    ap = Psn;
 	    len = (MALLOC_S)(Psn * sizeof(struct proc));
 	    if (!(Ps = (struct proc *)realloc((MALLOC_P *)Ps, len))) {
 		(void) fprintf(stderr,
@@ -1239,7 +1275,7 @@ ncache_isroot(na, cp)
 		buf[len++] = '/';
 	    (void) strcpy(&buf[len], cp);
 	    if (statsafely(buf, &sb) != 0
-	    ||  (unsigned long)sb.st_ino != Lf->inode)
+	    ||  (INODETYPE)sb.st_ino != Lf->inode)
 		return(0);
 	}
 /*
@@ -1520,9 +1556,9 @@ ncache_lookup(buf, blen, fp)
 	    for (mtp = readmnt(); mtp; mtp = mtp->next) {
 		if (!mtp->dir || !mtp->inode)
 		    continue;
-		if (Lf->dev == mtp->dev
-		&&  (unsigned long)mtp->inode == Lf->inode
-		&&  strcmp(mtp->dir, Lf->fsdir) == 0)
+		if ((Lf->dev == mtp->dev)
+		&&  (mtp->inode == Lf->inode)
+		&&  (strcmp(mtp->dir, Lf->fsdir) == 0))
 		    return(cp);
 	    }
 	    return((char *)NULL);
