@@ -35,7 +35,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode1.c,v 1.9 2005/08/08 19:49:23 abe Exp $";
+static char *rcsid = "$Id: dnode1.c,v 1.10 2008/10/21 16:16:06 abe Exp abe $";
 #endif
 
 
@@ -122,7 +122,7 @@ read_iso_node(v, d, dd, ino, nl, sz)
 	{
 
 # if	defined(HAS_NO_SI_UDEV)
-	    *d = dev2udev(&udev);
+	    *d = Dev2Udev(&udev);
 # else	/* !defined(HAS_NO_SI_UDEV) */
 	    *d = udev.si_udev;
 # endif	/* defined(HAS_NO_SI_UDEV) */
