@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: lsof.h,v 1.67 2014/10/13 22:36:20 abe Exp $
+ * $Id: lsof.h,v 1.68 2015/07/07 20:16:58 abe Exp $
  */
 
 
@@ -80,6 +80,24 @@ struct l_dev {
 };
 
 
+# if	defined(HASEPTOPTS)
+/*
+ * End point definitions
+ */
+
+#define	CHEND_PIPE	1		/* pipe endpoint ID */
+#define	EPT_PIPE	1		/* process has pipe file */
+#define	EPT_PIPE_END	2		/* process has pipe end point file */
+
+#  if	defined(HASUXSOCKEPT)
+#define	CHEND_UXS	2		/* UNIX socket endpoint ID */
+#define	EPT_UXS		4		/* process has a UNIX socket file */
+#define	EPT_UXS_END	8		/* process has a UNIX socket end point
+					 * file */
+#  endif	/* defined(HASUXSOCKEPT) */
+# endif	/* defined(HASEPTOPTS) */
+
+
 /*
  * FILE_FLAG column names
  */
@@ -455,12 +473,6 @@ extern int ZoneColW;
 					 * by PID or UID */
 #define	PS_SEC		2		/* secondary process selection -- e.g.,
 					 * by directory or file */
-
-# if	defined(HASEPTOPTS)
-#define	PS_PIPE		1		/* process has a pipe file */
-#define	PS_PIPE_END	2		/* process has a pipe end point file */
-# endif	/* defined(HASEPTOPTS) */
-
 #define	SELCMD		0x0001		/* select process by command name */
 #define	SELCNTX		0x0002		/* select security context (-Z) */
 #define	SELFD		0x0004		/* select file by descriptor name */
@@ -478,6 +490,8 @@ extern int ZoneColW;
 #define	SELTASK		0x4000		/* select tasks (-K) */
 #define	SELPINFO	0x8000		/* selected for pipe info (cleared in
 					 * link_lfile() */
+#define	SELUXSINFO	0x10000		/* selected for UNIX socket info
+					 * cleared in link_lfile() */
 #define	SELALL		(SELCMD|SELCNTX|SELFD|SELNA|SELNET|SELNM|SELNFS|SELPID|SELUID|SELUNX|SELZONE|SELTASK)
 #define	SELPROC		(SELCMD|SELCNTX|SELPGID|SELPID|SELUID|SELZONE|SELTASK)
 					/* process selecters */
@@ -554,12 +568,34 @@ struct pff_tab {			/* print file flags table structure */
 # endif	/* defined(HASFSTRUCT) */
 
 # if	defined(HASEPTOPTS)
-typedef struct pinfo {			/* hashed pipe inode numbers */
-	INODETYPE ino;			/* pipe's inode */
-	struct lfile *lf;		/* connected pipe file */
+typedef struct pxinfo {			/* hashed pipe or UNIX socket inode
+					 * information */
+	INODETYPE ino;			/* file's inode */
+	struct lfile *lf;		/* connected peer file */
 	int lpx;			/* connected process index */
-	struct pinfo *next;		/* next entry for hashed inode */
-} pinfo_t;
+	struct pxinfo *next;		/* next entry for hashed inode */
+} pxinfo_t;
+
+typedef struct uxsin {			/* UNIX socket information */
+	INODETYPE inode;		/* node number */
+	char *pcb;			/* protocol control block */
+	char *path;			/* file path */
+	unsigned char sb_def;		/* stat(2) buffer definitions */
+	dev_t sb_dev;			/* stat(2) buffer device */
+	INODETYPE sb_ino;		/* stat(2) buffer node number */
+	dev_t sb_rdev;			/* stat(2) raw device number */
+	uint32_t ty;			/* socket type */
+
+#  if	defined(HASEPTOPTS) && defined(HASUXSOCKEPT)
+	struct uxsin *icons;		/* incoming socket conections */
+	unsigned int icstat;		/* incoming connection status
+					 * 0 == none */
+	pxinfo_t *pxinfo;		/* inode information */
+	struct uxsin *peer;	        /* connected peer(s) info */
+#  endif	/* defined(HASEPTOPTS) && defined(HASUXSOCKEPT) */
+
+	struct uxsin *next;
+} uxsin_t;
 # endif	/* defined(HASEPTOPTS) */
 
 
@@ -639,7 +675,7 @@ extern int Fnfs;
 extern int Fnlink;
 extern int Foffset;
 extern int Fovhd;
-extern int FpipeE;
+extern int FeptE;
 
 extern int Fport;
 
@@ -725,7 +761,8 @@ struct lfile {
 	unsigned char off_def;		/* offset definition status */
 
 # if	defined(HASEPTOPTS)
-	unsigned char pipend;		/* pipe endpoint file */
+	unsigned char chend;		/* communication channel endpoint
+					 * file */
 # endif	/* defined(HASEPTOPTS) */
 
 	unsigned char rdev_def;		/* rdev definition status */
@@ -738,7 +775,7 @@ struct lfile {
 	char fd[FDLEN];
 	char iproto[IPROTOL];
 	char type[TYPEL];
-	short sf;			/* select flags -- SEL* symbols */
+	unsigned int sf;		/* select flags -- SEL* symbols */
 	int ch;				/* VMPC channel: -1 = none */
 	int ntype;			/* node type -- N_* value */
 	SZOFFTYPE off;
@@ -864,7 +901,7 @@ struct lproc {
 				 	 *	  1 = wholly selected
 				 	 *	  2 = partially selected */
 # if	defined(HASEPTOPTS)
-	short pipe;			/* pipe status -- PS_PIPE* values */
+	short ept;			/* end point status -- EPT_* values */
 # endif	/* defined(HASEPTOPTS) */
 
 	int pid;			/* process ID */
