@@ -32,20 +32,13 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: proc.c,v 1.48 2014/10/13 22:36:20 abe Exp $";
+static char *rcsid = "$Id: proc.c,v 1.49 2015/07/07 20:16:58 abe Exp $";
 #endif
 
 
 #include "lsof.h"
 
 
-/*
- * Local function prototypes
- */
-
-_PROTOTYPE(static int is_file_sel,(struct lproc *lp, struct lfile *lf));
-
-
 /*
  * add_nma() - add to NAME column addition
  */
@@ -60,12 +53,12 @@ add_nma(cp, len)
 	if (!cp || !len)
 	    return;
 	if (Lf->nma) {
-	    nl = (int)strlen(Lf->nma);
-	    Lf->nma = (char *)realloc((MALLOC_P *)Lf->nma,
-				      (MALLOC_S)(len + nl + 2));
+	    nl = (int) strlen(Lf->nma);
+	    Lf->nma = (char *) realloc((MALLOC_P *)Lf->nma,
+				       (MALLOC_S)(len + nl + 2));
 	} else {
 	    nl = 0;
-	    Lf->nma = (char *)malloc((MALLOC_S)(len + 1));
+	    Lf->nma = (char *) malloc((MALLOC_S)(len + 1));
 	}
 	if (!Lf->nma) {
 	    (void) fprintf(stderr, "%s: no name addition space: PID %ld, FD %s",
@@ -170,7 +163,7 @@ alloc_lfile(nm, num)
 #endif	/* defined(HASMNTSTAT) */
 
 #if	defined(HASEPTOPTS)
-	Lf->pipend = 0;
+	Lf->chend = 0;
 #endif	/* defined(HASEPTOPTS) */
 
 #if	defined(HASSOOPT)
@@ -308,7 +301,7 @@ alloc_lproc(pid, pgid, ppid, uid, cmd, pss, sf)
 	Lp->pid = pid;
 
 #if	defined(HASEPTOPTS)
-	Lp->pipe = 0;
+	Lp->ept = 0;
 #endif	/* defined(HASEPTOPTS) */
 
 #if	defined(HASTASKS)
@@ -639,7 +632,7 @@ is_cmd_excl(cmd, pss, sf)
  * is_file_sel() - is file selected?
  */
 
-static int
+int
 is_file_sel(lp, lf)
 	struct lproc *lp;		/* lproc structure pointer */
 	struct lfile *lf;		/* lfile structure pointer */
@@ -894,20 +887,33 @@ link_lfile()
 #if	defined(HASEPTOPTS)
 /*
  * If endpoint info has been requested, clear the SELPINFO flag from the local
- * file structure, since it was set only to insure this file would be linked.
- * While this might leave no file selection flags set, a later call to the
- * process_pinfo() function might set some. Also set the PS_PIPE flag for
- * the process.
- *
- * Also set the SELPINFO flag for the process.
+ * pipe file structure, since it was set only to insure this file would be
+ * linked.  While this might leave no file selection flags set, a later call
+ * to the process_pinfo() function might set some.  Also set the EPT_PIPE flag.
  */
-	if (FpipeE) {
-	    Lf->sf &= ~SELPINFO;
-	    Lp->pipe |= PS_PIPE;
+	if (FeptE) {
+	    if (Lf->sf & SELPINFO) {
+		Lp->ept |= EPT_PIPE;
+		Lf->sf &= ~SELPINFO;
+	    }
+
+# if	defined(HASUXSOCKEPT)
+/*
+ * Process UNIX socket endpoint files the same way by clearing the SELUXINFO
+ * flag and setting the EPT_UXS flag, letting a later call to process_uxsinfo()
+ * set selection flags.
+ */
+	    if (Lf->sf & SELUXSINFO) {
+		Lp->ept |= EPT_UXS;
+		Lf->sf &= ~SELUXSINFO;
+	    }
+# endif	/* defined(HASUXSOCKEPT) */
+
 	}
 #endif	/* defined(HASEPTOPTS) */
 
-	Lp->pss |= PS_SEC;
+	if (Lf->sf)
+	    Lp->pss |= PS_SEC;
 	if (Plf)
 	    Plf->next = Lf;
 	else
@@ -940,14 +946,14 @@ process_pinfo(f)
 	struct lfile *ef;		/* pipe endpoint file */
 	int i;				/* temporary index */
 	char nma[1024];			/* name addition buffer */
-	pinfo_t *pp;			/* previous pipe info */
+	pxinfo_t *pp;			/* previous pipe info */
 	
-	if (!FpipeE)
+	if (!FeptE)
 	    return;
 	for (Lf = Lp->file; Lf; Lf = Lf->next) {
 	    if ((Lf->ntype != N_FIFO) || (Lf->inp_ty != 1))
 		continue;
-	    pp = (pinfo_t *)NULL;
+	    pp = (pxinfo_t *)NULL;
 	    switch(f) {
 	    case 0:
 
@@ -957,8 +963,8 @@ process_pinfo(f)
 		if (is_file_sel(Lp, Lf)) {
 
 		/*
-		 * This file has been selected by some criterion other than its
-		 * being a pipe.  Look up the pipe's endpoints.
+		 * This file has been selected by some criterion other than
+		 * its being a pipe.  Look up the pipe's endpoints.
 		 */
 		    do {
 			if ((pp = find_pendinfo(Lf, pp))) {
@@ -978,14 +984,14 @@ process_pinfo(f)
 				ep->pid, CmdLim, ep->cmd,&ef->fd[i],
 				ef->access);
 			    (void) add_nma(nma, strlen(nma));
-			    if (FpipeE == 2) {
+			    if (FeptE == 2) {
 
 			    /*
 			     * Endpoint files have been selected, so mark this
-			     * one for selection later.
+			     * one for selection later. Set the type to PIPE.
 			     */
-				ef->pipend = 1;
-				ep->pipe |= PS_PIPE_END;
+				ef->chend = CHEND_PIPE;
+				ep->ept |= EPT_PIPE_END;
 			    }
 			    pp = pp->next;
 			}
@@ -993,7 +999,7 @@ process_pinfo(f)
 		}
 		break;
 	    case 1:
-		if (!is_file_sel(Lp, Lf) && Lf->pipend) {
+		if (!is_file_sel(Lp, Lf) && (Lf->chend & CHEND_PIPE)) {
 
 		/*
 		 * This is an unselected end point file.  Select it and add
